@@ -1,6 +1,3 @@
-#![allow(dead_code)]
-#![allow(unused_macros)]
-
 const INV_DIM: &str = "Error: Dimensions did not match.";
 
 /**
@@ -9,7 +6,7 @@ Mathematical Vectors in Rust.
 pub struct MathVector {
     values:    Vec<f64>,
     dimension: usize,
-    length:    f64,
+    length:    Option<f64>,
 }
 
 impl MathVector {
@@ -25,16 +22,31 @@ impl MathVector {
     pub fn new(values: &Vec<f64>) -> MathVector {        
         MathVector { values:    values.clone(),
                      dimension: values.len(),
-                     length:    -1f64 }
+                     length:    None }
+    }
+    /**
+    Creates a new `MathVector` with the specified capacity.
+
+    # Arguments
+    * `dim` - The dimension for the new MathVector.
+
+    # Returns
+    A new MathVector with length 0.
+    */
+    pub fn new_with_dimension(dim: usize) -> MathVector {
+
+        MathVector { values:    vec![0f64; dim],
+                     dimension: dim,
+                     length:    None }
     }
     /**
     Gets the dimension in which a `MathVector` lives.
 
     # Returns
-    A `usize`.
+    A `&usize`.
     */
-    pub fn dimension(self: &Self) -> usize {
-        self.dimension
+    pub fn dimension(self: &Self) -> &usize {
+        &self.dimension
     }
     /**
     Gets the length of a `MathVector`.
@@ -43,15 +55,16 @@ impl MathVector {
     A `f64`.
     */
     pub fn length(self: &mut Self) -> f64 {
-        match self.length < 0f64 {
-            true  => { let mut len: f64 = 0f64; 
-                       for i in &self.values {
-                           len += i * i;
-                       }
-                       self.length = len;
-                       return self.length;
-                     }
-            false => { return self.length; }
+        match self.length {
+            None        => { let mut len: f64 = 0f64; 
+                             for i in &self.values {
+                                 len += i * i;
+                             }
+                             len = len.sqrt();
+                             self.length = Some(len);
+                             return len;
+                           }
+            Some(len) => { return len; }
 
         }
     }
@@ -59,7 +72,7 @@ impl MathVector {
     Gets the values of a `MathVector`.
 
     # Returns
-    A `Vec<f64>`.
+    A `&Vec<f64>`.
     */
     pub fn get_values(self: &Self) -> &'_ Vec<f64> {
         &self.values
@@ -76,11 +89,7 @@ impl MathVector {
     pub fn set_values(self: &mut Self, vals: &Vec<f64>) {
         match vals.len() == self.dimension {
             true  => { self.values = vals.clone();
-                       let mut len: f64 = 0f64; 
-                       for i in &self.values {
-                           len += i * i;
-                       }
-                       self.length = len.sqrt(); }
+                       self.length = None; }
             false => { core::panic!("{}", INV_DIM); } 
         }
     }
@@ -89,7 +98,7 @@ impl MathVector {
 impl std::ops::Add for MathVector {
     type Output = Self;
     fn add(self, other: Self) -> MathVector {
-        match self.dimension() == other.dimension {
+        match self.dimension() == &other.dimension {
             true  =>  { 
                 let mut vals: Vec<f64> = Vec::with_capacity(self.dimension);
                 for i in 0..self.dimension {
@@ -97,7 +106,7 @@ impl std::ops::Add for MathVector {
                 }
                 MathVector { values:    vals,
                              dimension: self.dimension,
-                             length:    -1f64 }
+                             length:    None }
             }
             false => { core::panic!("{}", INV_DIM) }
         }
@@ -110,12 +119,12 @@ impl std::ops::Sub for MathVector {
         match self.dimension() == other.dimension() {
             true  =>  { 
                 let mut vals: Vec<f64> = Vec::with_capacity(self.dimension);
-                for i in 0..self.dimension() {
+                for i in 0..self.dimension {
                     vals.push(self.values[i] - other.values[i]);
                 }
                 MathVector { values:    vals,
                              dimension: self.dimension,
-                             length:    -1f64 }
+                             length:    None }
             }
             false => { core::panic!("{}", INV_DIM) }
         }
@@ -140,15 +149,15 @@ pub fn scalar_mul(scalar: f64, other: &MathVector) -> MathVector {
     }
     MathVector { values:    vals,
                  dimension: other.dimension,
-                 length:    -1f64 }
+                 length:    None }
 }
 
-    /**
-    Creates a new `MathVector` more elegantly from values..
+/**
+Creates a new `MathVector` more elegantly from values.
 
-    # Returns
-    A new `MathVector`.
-    */
+# Returns
+A new `MathVector`.
+*/
 #[macro_export]
 macro_rules! new_mathvec {
     ( $( $a:expr ),* ) => {
@@ -162,19 +171,23 @@ macro_rules! new_mathvec {
     };
 }
 
-#[test]
-fn test_macro() {
-    println!("{}", new_mathvec!(2,2,2));
-}
-
 impl std::fmt::Display for MathVector {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         let mut finstring: String = "( ".to_owned();
         for i in 0..self.dimension {
-            finstring =  " ".to_owned() + &finstring + &self.values[i].to_string() + ";";
+            finstring =  " ".to_owned() + &finstring + &self.values[i].to_string() + "; ";
         }
-        finstring.pop();
-        finstring = finstring + " )";
-        write!(f, "{}", finstring)
+        finstring.drain(finstring.len()-2..finstring.len());
+        write!(f, "{} )", finstring)
+    }
+}
+
+impl PartialEq for MathVector {
+    fn eq(&self, other: &Self) -> bool {
+        self.values == other.values
+    }
+
+    fn ne(&self, other: &Self) -> bool {
+        !(self == other)
     }
 }
\ No newline at end of file
